@@ -1,18 +1,29 @@
 from .structs import Pair
 
 AAVE_CRO = Pair("AAVE_CRO", price_precision=2, quantity_precision=3)
+AAVE_USDC = Pair("AAVE_USDC", price_precision=2, quantity_precision=4)
 AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
 ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
 ADA_CRO = Pair("ADA_CRO", price_precision=3, quantity_precision=2)
+ADA_USDC = Pair("ADA_USDC", price_precision=5, quantity_precision=1)
 ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
+AGLD_USDT = Pair("AGLD_USDT", price_precision=4, quantity_precision=2)
 ALGO_BTC = Pair("ALGO_BTC", price_precision=8, quantity_precision=2)
 ALGO_CRO = Pair("ALGO_CRO", price_precision=3, quantity_precision=2)
+ALGO_USDC = Pair("ALGO_USDC", price_precision=4, quantity_precision=2)
 ALGO_USDT = Pair("ALGO_USDT", price_precision=4, quantity_precision=2)
+ALICE_USDT = Pair("ALICE_USDT", price_precision=3, quantity_precision=3)
+AMP_USDT = Pair("AMP_USDT", price_precision=5, quantity_precision=1)
 ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
+AR_USDC = Pair("AR_USDC", price_precision=3, quantity_precision=3)
 ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
 ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
 ATOM_USDT = Pair("ATOM_USDT", price_precision=3, quantity_precision=2)
+AUDIO_USDT = Pair("AUDIO_USDT", price_precision=4, quantity_precision=2)
+AVAX_BTC = Pair("AVAX_BTC", price_precision=7, quantity_precision=3)
+AVAX_USDC = Pair("AVAX_USDC", price_precision=3, quantity_precision=3)
 AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
+AXS_USDT = Pair("AXS_USDT", price_precision=4, quantity_precision=2)
 BAL_CRO = Pair("BAL_CRO", price_precision=2, quantity_precision=3)
 BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
 BAND_CRO = Pair("BAND_CRO", price_precision=3, quantity_precision=2)
@@ -24,68 +35,112 @@ BCH_CRO = Pair("BCH_CRO", price_precision=2, quantity_precision=3)
 BCH_USDT = Pair("BCH_USDT", price_precision=2, quantity_precision=5)
 BNT_CRO = Pair("BNT_CRO", price_precision=3, quantity_precision=2)
 BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
+BOSON_USDT = Pair("BOSON_USDT", price_precision=4, quantity_precision=2)
 BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
 BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
+C98_USDT = Pair("C98_USDT", price_precision=4, quantity_precision=2)
 CELR_CRO = Pair("CELR_CRO", price_precision=5, quantity_precision=1)
 CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
 CHR_USDT = Pair("CHR_USDT", price_precision=5, quantity_precision=1)
 CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
+CKB_USDT = Pair("CKB_USDT", price_precision=6, quantity_precision=0)
 COMP_CRO = Pair("COMP_CRO", price_precision=2, quantity_precision=3)
 COMP_USDT = Pair("COMP_USDT", price_precision=2, quantity_precision=5)
+COTI_USDC = Pair("COTI_USDC", price_precision=5, quantity_precision=1)
+CQT_USDT = Pair("CQT_USDT", price_precision=4, quantity_precision=2)
 CRO_BTC = Pair("CRO_BTC", price_precision=9, quantity_precision=2)
 CRO_USDC = Pair("CRO_USDC", price_precision=5, quantity_precision=3)
 CRO_USDT = Pair("CRO_USDT", price_precision=5, quantity_precision=3)
 CRV_CRO = Pair("CRV_CRO", price_precision=3, quantity_precision=2)
 CRV_USDT = Pair("CRV_USDT", price_precision=4, quantity_precision=4)
+CTSI_USDT = Pair("CTSI_USDT", price_precision=5, quantity_precision=1)
 DAI_CRO = Pair("DAI_CRO", price_precision=3, quantity_precision=3)
+DAI_USDC = Pair("DAI_USDC", price_precision=4, quantity_precision=2)
 DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
+DERC_USDT = Pair("DERC_USDT", price_precision=4, quantity_precision=2)
 DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
 DOGE_CRO = Pair("DOGE_CRO", price_precision=4, quantity_precision=2)
+DOGE_USDC = Pair("DOGE_USDC", price_precision=5, quantity_precision=1)
 DOGE_USDT = Pair("DOGE_USDT", price_precision=5, quantity_precision=2)
 DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
 DOT_CRO = Pair("DOT_CRO", price_precision=3, quantity_precision=3)
+DOT_USDC = Pair("DOT_USDC", price_precision=3, quantity_precision=3)
 DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
+DYDX_BTC = Pair("DYDX_BTC", price_precision=8, quantity_precision=3)
+DYDX_USDT = Pair("DYDX_USDT", price_precision=3, quantity_precision=3)
+EFI_BTC = Pair("EFI_BTC", price_precision=9, quantity_precision=2)
+EFI_USDT = Pair("EFI_USDT", price_precision=4, quantity_precision=2)
 EGLD_CRO = Pair("EGLD_CRO", price_precision=3, quantity_precision=2)
 EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
 ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
 ENJ_CRO = Pair("ENJ_CRO", price_precision=3, quantity_precision=2)
+ENJ_USDC = Pair("ENJ_USDC", price_precision=4, quantity_precision=2)
 ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
 EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
-EOS_CRO = Pair("EOS_CRO", price_precision=3, quantity_precision=2)
 EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
+ETC_BTC = Pair("ETC_BTC", price_precision=7, quantity_precision=3)
+ETC_USDT = Pair("ETC_USDT", price_precision=3, quantity_precision=3)
 ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
 ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
+ETH_USDC = Pair("ETH_USDC", price_precision=2, quantity_precision=5)
 ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
+FARM_USDC = Pair("FARM_USDC", price_precision=2, quantity_precision=4)
+FET_USDT = Pair("FET_USDT", price_precision=5, quantity_precision=1)
 FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
 FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
 FLOW_CRO = Pair("FLOW_CRO", price_precision=2, quantity_precision=3)
 FLOW_USDT = Pair("FLOW_USDT", price_precision=3, quantity_precision=4)
+FORTH_USDT = Pair("FORTH_USDT", price_precision=3, quantity_precision=3)
+FTM_BTC = Pair("FTM_BTC", price_precision=9, quantity_precision=2)
+FTM_USDT = Pair("FTM_USDT", price_precision=4, quantity_precision=2)
+FXS_USDC = Pair("FXS_USDC", price_precision=4, quantity_precision=2)
+GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
 GRT_CRO = Pair("GRT_CRO", price_precision=3, quantity_precision=2)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
+GTC_USDT = Pair("GTC_USDT", price_precision=3, quantity_precision=3)
+HNT_USDT = Pair("HNT_USDT", price_precision=3, quantity_precision=3)
 HOT_CRO = Pair("HOT_CRO", price_precision=5, quantity_precision=0)
 HOT_USDT = Pair("HOT_USDT", price_precision=6, quantity_precision=0)
+ICP_USDT = Pair("ICP_USDT", price_precision=3, quantity_precision=3)
 ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
 ICX_CRO = Pair("ICX_CRO", price_precision=3, quantity_precision=0)
 ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
+ILV_USDT = Pair("ILV_USDT", price_precision=2, quantity_precision=4)
+INJ_USDT = Pair("INJ_USDT", price_precision=3, quantity_precision=3)
+IQ_USDT = Pair("IQ_USDT", price_precision=6, quantity_precision=0)
 KAVA_USDT = Pair("KAVA_USDT", price_precision=4, quantity_precision=2)
+KEEP_USDT = Pair("KEEP_USDT", price_precision=5, quantity_precision=1)
+KLAY_USDT = Pair("KLAY_USDT", price_precision=4, quantity_precision=2)
 KNC_CRO = Pair("KNC_CRO", price_precision=3, quantity_precision=2)
 KNC_USDT = Pair("KNC_USDT", price_precision=4, quantity_precision=3)
 KSM_CRO = Pair("KSM_CRO", price_precision=2, quantity_precision=3)
+KSM_USDC = Pair("KSM_USDC", price_precision=2, quantity_precision=4)
 KSM_USDT = Pair("KSM_USDT", price_precision=3, quantity_precision=3)
 LINK_BTC = Pair("LINK_BTC", price_precision=7, quantity_precision=2)
 LINK_CRO = Pair("LINK_CRO", price_precision=2, quantity_precision=2)
+LINK_USDC = Pair("LINK_USDC", price_precision=3, quantity_precision=3)
 LINK_USDT = Pair("LINK_USDT", price_precision=3, quantity_precision=2)
-LRC_CRO = Pair("LRC_CRO", price_precision=4, quantity_precision=2)
+LPT_USDC = Pair("LPT_USDC", price_precision=3, quantity_precision=3)
 LRC_USDT = Pair("LRC_USDT", price_precision=5, quantity_precision=2)
 LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
 LTC_CRO = Pair("LTC_CRO", price_precision=2, quantity_precision=4)
+LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
 LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
+LUNA_USDC = Pair("LUNA_USDC", price_precision=3, quantity_precision=3)
+LUNA_USDT = Pair("LUNA_USDT", price_precision=4, quantity_precision=2)
 MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
 MANA_CRO = Pair("MANA_CRO", price_precision=3, quantity_precision=2)
 MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
+MASK_USDT = Pair("MASK_USDT", price_precision=4, quantity_precision=2)
+MATIC_BTC = Pair("MATIC_BTC", price_precision=9, quantity_precision=0)
+MATIC_USDC = Pair("MATIC_USDC", price_precision=5, quantity_precision=1)
 MATIC_USDT = Pair("MATIC_USDT", price_precision=5, quantity_precision=2)
+MIR_USDT = Pair("MIR_USDT", price_precision=4, quantity_precision=2)
 MKR_CRO = Pair("MKR_CRO", price_precision=2, quantity_precision=3)
 MKR_USDT = Pair("MKR_USDT", price_precision=2, quantity_precision=6)
+MLN_USDC = Pair("MLN_USDC", price_precision=3, quantity_precision=3)
+NANO_USDT = Pair("NANO_USDT", price_precision=4, quantity_precision=2)
+NEAR_BTC = Pair("NEAR_BTC", price_precision=8, quantity_precision=2)
 NEAR_CRO = Pair("NEAR_CRO", price_precision=3, quantity_precision=2)
 NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
 NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
@@ -100,34 +155,54 @@ OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
 ONEINCH_USDT = Pair("1INCH_USDT", price_precision=4, quantity_precision=2)
 ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
 ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
-ONT_CRO = Pair("ONT_CRO", price_precision=3, quantity_precision=2)
 ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
-PAXG_CRO = Pair("PAXG_CRO", price_precision=2, quantity_precision=4)
 PAXG_USDT = Pair("PAXG_USDT", price_precision=2, quantity_precision=5)
+PENDLE_USDT = Pair("PENDLE_USDT", price_precision=5, quantity_precision=1)
+PLA_USDT = Pair("PLA_USDT", price_precision=5, quantity_precision=1)
+POLY_USDC = Pair("POLY_USDC", price_precision=5, quantity_precision=1)
+QNT_USDC = Pair("QNT_USDC", price_precision=2, quantity_precision=4)
+QNT_USDT = Pair("QNT_USDT", price_precision=2, quantity_precision=4)
 QTUM_CRO = Pair("QTUM_CRO", price_precision=3, quantity_precision=2)
 QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
+QUICK_USDT = Pair("QUICK_USDT", price_precision=2, quantity_precision=4)
+RAD_USDC = Pair("RAD_USDC", price_precision=3, quantity_precision=3)
+RARI_USDC = Pair("RARI_USDC", price_precision=3, quantity_precision=3)
+RARI_USDT = Pair("RARI_USDT", price_precision=3, quantity_precision=3)
 REN_CRO = Pair("REN_CRO", price_precision=4, quantity_precision=2)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
+RLC_USDT = Pair("RLC_USDT", price_precision=3, quantity_precision=3)
 RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
-SAND_CRO = Pair("SAND_CRO", price_precision=4, quantity_precision=2)
+RSR_USDT = Pair("RSR_USDT", price_precision=5, quantity_precision=1)
+RUNE_USDT = Pair("RUNE_USDT", price_precision=3, quantity_precision=3)
 SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
+SC_USDT = Pair("SC_USDT", price_precision=6, quantity_precision=0)
+SHIB_USDC = Pair("SHIB_USDC", price_precision=9, quantity_precision=0)
+SHIB_USDT = Pair("SHIB_USDT", price_precision=9, quantity_precision=0)
 SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
+SLP_USDT = Pair("SLP_USDT", price_precision=5, quantity_precision=1)
 SNX_CRO = Pair("SNX_CRO", price_precision=2, quantity_precision=3)
 SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
+SOL_BTC = Pair("SOL_BTC", price_precision=7, quantity_precision=3)
+SOL_USDC = Pair("SOL_USDC", price_precision=3, quantity_precision=3)
 SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
 STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
 STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
 SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
+TFUEL_USDT = Pair("TFUEL_USDT", price_precision=5, quantity_precision=1)
 THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
+TRB_USDT = Pair("TRB_USDT", price_precision=3, quantity_precision=3)
 UMA_BTC = Pair("UMA_BTC", price_precision=7, quantity_precision=4)
 UMA_CRO = Pair("UMA_CRO", price_precision=2, quantity_precision=4)
 UMA_USDT = Pair("UMA_USDT", price_precision=3, quantity_precision=4)
 UNI_CRO = Pair("UNI_CRO", price_precision=3, quantity_precision=2)
+UNI_USDC = Pair("UNI_USDC", price_precision=3, quantity_precision=3)
 UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
 USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
 VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
 VET_CRO = Pair("VET_CRO", price_precision=4, quantity_precision=0)
+VET_USDC = Pair("VET_USDC", price_precision=6, quantity_precision=0)
 VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
+VTHO_USDT = Pair("VTHO_USDT", price_precision=6, quantity_precision=0)
 WAVES_USDT = Pair("WAVES_USDT", price_precision=3, quantity_precision=3)
 WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
 WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
@@ -136,6 +211,7 @@ XLM_CRO = Pair("XLM_CRO", price_precision=3, quantity_precision=2)
 XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
 XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
 XRP_CRO = Pair("XRP_CRO", price_precision=3, quantity_precision=0)
+XRP_USDC = Pair("XRP_USDC", price_precision=5, quantity_precision=1)
 XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
 XTZ_BTC = Pair("XTZ_BTC", price_precision=8, quantity_precision=2)
 XTZ_CRO = Pair("XTZ_CRO", price_precision=3, quantity_precision=2)
@@ -143,6 +219,7 @@ XTZ_USDT = Pair("XTZ_USDT", price_precision=4, quantity_precision=2)
 YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=6)
 YFI_CRO = Pair("YFI_CRO", price_precision=2, quantity_precision=6)
 YFI_USDT = Pair("YFI_USDT", price_precision=2, quantity_precision=6)
+YGG_USDT = Pair("YGG_USDT", price_precision=4, quantity_precision=2)
 ZIL_CRO = Pair("ZIL_CRO", price_precision=4, quantity_precision=2)
 ZIL_USDT = Pair("ZIL_USDT", price_precision=5, quantity_precision=1)
 ZRX_USDT = Pair("ZRX_USDT", price_precision=4, quantity_precision=2)
